@@ -10,11 +10,14 @@
 //
 //
 
-#include <stdio.h>
-#include <stdlib.h>
+#include <cstdio>
+#include <cstdlib>
+#include <cstring>
 
 #include "fileutils.h"
 
+using namespace std;
+
 char *
 create_filename (char *name, char *ext)
 {
