@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,96 +54,21 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 1
 
 
 
-/* Tokens.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     TOK_PACKAGE = 258,
-     TOK_VERSION = 259,
-     TOK_OPTION = 260,
-     TOK_DEFGROUP = 261,
-     TOK_GROUPOPTION = 262,
-     TOK_DEFMODE = 263,
-     TOK_MODEOPTION = 264,
-     TOK_YES = 265,
-     TOK_NO = 266,
-     TOK_ON = 267,
-     TOK_OFF = 268,
-     TOK_FLAG = 269,
-     TOK_PURPOSE = 270,
-     TOK_DESCRIPTION = 271,
-     TOK_USAGE = 272,
-     TOK_DEFAULT = 273,
-     TOK_GROUP = 274,
-     TOK_GROUPDESC = 275,
-     TOK_MODE = 276,
-     TOK_MODEDESC = 277,
-     TOK_MULTIPLE = 278,
-     TOK_ARGOPTIONAL = 279,
-     TOK_TYPESTR = 280,
-     TOK_SECTION = 281,
-     TOK_DETAILS = 282,
-     TOK_SECTIONDESC = 283,
-     TOK_TEXT = 284,
-     TOK_ARGS = 285,
-     TOK_VALUES = 286,
-     TOK_HIDDEN = 287,
-     TOK_DEPENDON = 288,
-     TOK_STRING = 289,
-     TOK_CHAR = 290,
-     TOK_ARGTYPE = 291,
-     TOK_SIZE = 292
-   };
-#endif
-/* Tokens.  */
-#define TOK_PACKAGE 258
-#define TOK_VERSION 259
-#define TOK_OPTION 260
-#define TOK_DEFGROUP 261
-#define TOK_GROUPOPTION 262
-#define TOK_DEFMODE 263
-#define TOK_MODEOPTION 264
-#define TOK_YES 265
-#define TOK_NO 266
-#define TOK_ON 267
-#define TOK_OFF 268
-#define TOK_FLAG 269
-#define TOK_PURPOSE 270
-#define TOK_DESCRIPTION 271
-#define TOK_USAGE 272
-#define TOK_DEFAULT 273
-#define TOK_GROUP 274
-#define TOK_GROUPDESC 275
-#define TOK_MODE 276
-#define TOK_MODEDESC 277
-#define TOK_MULTIPLE 278
-#define TOK_ARGOPTIONAL 279
-#define TOK_TYPESTR 280
-#define TOK_SECTION 281
-#define TOK_DETAILS 282
-#define TOK_SECTIONDESC 283
-#define TOK_TEXT 284
-#define TOK_ARGS 285
-#define TOK_VALUES 286
-#define TOK_HIDDEN 287
-#define TOK_DEPENDON 288
-#define TOK_STRING 289
-#define TOK_CHAR 290
-#define TOK_ARGTYPE 291
-#define TOK_SIZE 292
-
-
-
-
 /* Copy the first part of user declarations.  */
-#line 22 "parser.yy"
+
+/* Line 189 of yacc.c  */
+#line 22 "../../src/parser.yy"
 
 
 #ifdef HAVE_CONFIG_H
@@ -267,6 +191,9 @@ struct multiple_size
 
 
 
+/* Line 189 of yacc.c  */
+#line 196 "../../src/parser.cc"
+
 /* Enabling traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -285,10 +212,97 @@ struct multiple_size
 # define YYTOKEN_TABLE 0
 #endif
 
+
+/* Tokens.  */
+#ifndef YYTOKENTYPE
+# define YYTOKENTYPE
+   /* Put the tokens into the symbol table, so that GDB and other debuggers
+      know about them.  */
+   enum yytokentype {
+     TOK_PACKAGE = 258,
+     TOK_VERSION = 259,
+     TOK_OPTION = 260,
+     TOK_DEFGROUP = 261,
+     TOK_GROUPOPTION = 262,
+     TOK_DEFMODE = 263,
+     TOK_MODEOPTION = 264,
+     TOK_YES = 265,
+     TOK_NO = 266,
+     TOK_ON = 267,
+     TOK_OFF = 268,
+     TOK_FLAG = 269,
+     TOK_PURPOSE = 270,
+     TOK_DESCRIPTION = 271,
+     TOK_USAGE = 272,
+     TOK_DEFAULT = 273,
+     TOK_GROUP = 274,
+     TOK_GROUPDESC = 275,
+     TOK_MODE = 276,
+     TOK_MODEDESC = 277,
+     TOK_MULTIPLE = 278,
+     TOK_ARGOPTIONAL = 279,
+     TOK_TYPESTR = 280,
+     TOK_SECTION = 281,
+     TOK_DETAILS = 282,
+     TOK_SECTIONDESC = 283,
+     TOK_TEXT = 284,
+     TOK_ARGS = 285,
+     TOK_VALUES = 286,
+     TOK_HIDDEN = 287,
+     TOK_DEPENDON = 288,
+     TOK_STRING = 289,
+     TOK_CHAR = 290,
+     TOK_ARGTYPE = 291,
+     TOK_SIZE = 292
+   };
+#endif
+/* Tokens.  */
+#define TOK_PACKAGE 258
+#define TOK_VERSION 259
+#define TOK_OPTION 260
+#define TOK_DEFGROUP 261
+#define TOK_GROUPOPTION 262
+#define TOK_DEFMODE 263
+#define TOK_MODEOPTION 264
+#define TOK_YES 265
+#define TOK_NO 266
+#define TOK_ON 267
+#define TOK_OFF 268
+#define TOK_FLAG 269
+#define TOK_PURPOSE 270
+#define TOK_DESCRIPTION 271
+#define TOK_USAGE 272
+#define TOK_DEFAULT 273
+#define TOK_GROUP 274
+#define TOK_GROUPDESC 275
+#define TOK_MODE 276
+#define TOK_MODEDESC 277
+#define TOK_MULTIPLE 278
+#define TOK_ARGOPTIONAL 279
+#define TOK_TYPESTR 280
+#define TOK_SECTION 281
+#define TOK_DETAILS 282
+#define TOK_SECTIONDESC 283
+#define TOK_TEXT 284
+#define TOK_ARGS 285
+#define TOK_VALUES 286
+#define TOK_HIDDEN 287
+#define TOK_DEPENDON 288
+#define TOK_STRING 289
+#define TOK_CHAR 290
+#define TOK_ARGTYPE 291
+#define TOK_SIZE 292
+
+
+
+
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 144 "parser.yy"
 {
+
+/* Line 214 of yacc.c  */
+#line 144 "../../src/parser.yy"
+
     char   *str;
     char    chr;
     int	    argtype;
@@ -296,13 +310,15 @@ typedef union YYSTYPE
     class AcceptedValues *ValueList;
     struct gengetopt_option *gengetopt_option;
     struct multiple_size *multiple_size;
-}
-/* Line 187 of yacc.c.  */
-#line 302 "parser.cc"
-	YYSTYPE;
+
+
+
+/* Line 214 of yacc.c  */
+#line 318 "../../src/parser.cc"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 #if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
@@ -322,8 +338,8 @@ typedef struct YYLTYPE
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 327 "parser.cc"
+/* Line 264 of yacc.c  */
+#line 343 "../../src/parser.cc"
 
 #ifdef short
 # undef short
@@ -398,14 +414,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -487,9 +503,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-    YYLTYPE yyls;
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+  YYLTYPE yyls_alloc;
 };
 
 /* The size of the maximum gap between one aligned stack and the next.  */
@@ -524,12 +540,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -997,17 +1013,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep, yylocationp)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -1042,11 +1061,11 @@ yy_reduce_print (yyvsp, yylsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       , &(yylsp[(yyi + 1) - (yynrhs)])		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1328,10 +1347,8 @@ yydestruct (yymsg, yytype, yyvaluep, yylocationp)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1347,23 +1364,23 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
+/* Location data for the lookahead symbol.  */
+YYLTYPE yylloc;
+
 /* Number of syntax errors so far.  */
 int yynerrs;
-/* Location data for the look-ahead symbol.  */
-YYLTYPE yylloc;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1387,14 +1404,49 @@ yyparse ()
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+       `yyls': related to locations.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    /* The location stack.  */
+    YYLTYPE yylsa[YYINITDEPTH];
+    YYLTYPE *yyls;
+    YYLTYPE *yylsp;
+
+    /* The locations where the error started and ended.  */
+    YYLTYPE yyerror_range[2];
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+  YYLTYPE yyloc;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1402,63 +1454,37 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-  /* The location stack.  */
-  YYLTYPE yylsa[YYINITDEPTH];
-  YYLTYPE *yyls = yylsa;
-  YYLTYPE *yylsp;
-  /* The locations where the error started and ended.  */
-  YYLTYPE yyerror_range[2];
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N), yylsp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-  YYLTYPE yyloc;
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yyls = yylsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
   yylsp = yyls;
+
 #if YYLTYPE_IS_TRIVIAL
   /* Initialize the default location before parsing starts.  */
   yylloc.first_line   = yylloc.last_line   = 1;
-  yylloc.first_column = yylloc.last_column = 0;
+  yylloc.first_column = yylloc.last_column = 1;
 #endif
 
   goto yysetstate;
@@ -1497,6 +1523,7 @@ yyparse ()
 		    &yyvs1, yysize * sizeof (*yyvsp),
 		    &yyls1, yysize * sizeof (*yylsp),
 		    &yystacksize);
+
 	yyls = yyls1;
 	yyss = yyss1;
 	yyvs = yyvs1;
@@ -1518,9 +1545,9 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-	YYSTACK_RELOCATE (yyls);
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
+	YYSTACK_RELOCATE (yyls_alloc, yyls);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1541,6 +1568,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1549,16 +1579,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1590,20 +1620,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1644,7 +1670,9 @@ yyreduce:
   switch (yyn)
     {
         case 17:
-#line 230 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 230 "../../src/parser.yy"
     {
 	      if (gengetopt_package_given)
 		{
@@ -1664,7 +1692,9 @@ yyreduce:
     break;
 
   case 18:
-#line 250 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 250 "../../src/parser.yy"
     {
 	      if (gengetopt_version_given)
 		{
@@ -1684,7 +1714,9 @@ yyreduce:
     break;
 
   case 19:
-#line 270 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 270 "../../src/parser.yy"
     {
 	      if (gengetopt_purpose_given)
 		{
@@ -1704,7 +1736,9 @@ yyreduce:
     break;
 
   case 20:
-#line 290 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 290 "../../src/parser.yy"
     {
 	      if (gengetopt_description_given)
 		{
@@ -1724,7 +1758,9 @@ yyreduce:
     break;
 
   case 21:
-#line 310 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 310 "../../src/parser.yy"
     {
       if (gengetopt_usage_given)
       {
@@ -1744,28 +1780,36 @@ yyreduce:
     break;
 
   case 22:
-#line 331 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 331 "../../src/parser.yy"
     {
                 gengetopt_set_section ((yyvsp[(2) - (3)].str), (yyvsp[(3) - (3)].str));
               }
     break;
 
   case 23:
-#line 338 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 338 "../../src/parser.yy"
     {
   gengetopt_set_text((yyvsp[(2) - (2)].str));
             }
     break;
 
   case 24:
-#line 345 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 345 "../../src/parser.yy"
     {
   gengetopt_set_args((yyvsp[(2) - (2)].str));
             }
     break;
 
   case 25:
-#line 352 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 352 "../../src/parser.yy"
     {
               if (gengetopt_add_group ((yyvsp[(2) - (4)].str), (yyvsp[(3) - (4)].str), (yyvsp[(4) - (4)].boolean)))
                 {
@@ -1776,7 +1820,9 @@ yyreduce:
     break;
 
   case 26:
-#line 363 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 363 "../../src/parser.yy"
     {
               if (gengetopt_add_mode ((yyvsp[(2) - (3)].str), (yyvsp[(3) - (3)].str)))
                 {
@@ -1787,7 +1833,9 @@ yyreduce:
     break;
 
   case 27:
-#line 375 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 375 "../../src/parser.yy"
     {
           (yyvsp[(5) - (5)].gengetopt_option)->filename = gengetopt_input_filename;
           (yyvsp[(5) - (5)].gengetopt_option)->linenum = (yylsp[(1) - (5)]).first_line;
@@ -1805,7 +1853,9 @@ yyreduce:
     break;
 
   case 28:
-#line 394 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 394 "../../src/parser.yy"
     {
           (yyvsp[(5) - (5)].gengetopt_option)->filename = gengetopt_input_filename;
           (yyvsp[(5) - (5)].gengetopt_option)->linenum = (yylsp[(1) - (5)]).first_line;
@@ -1823,7 +1873,9 @@ yyreduce:
     break;
 
   case 29:
-#line 413 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 413 "../../src/parser.yy"
     {
           (yyvsp[(5) - (5)].gengetopt_option)->filename = gengetopt_input_filename;
           (yyvsp[(5) - (5)].gengetopt_option)->linenum = (yylsp[(1) - (5)]).first_line;
@@ -1841,7 +1893,9 @@ yyreduce:
     break;
 
   case 31:
-#line 437 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 437 "../../src/parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (2)].gengetopt_option);
 			  	(yyval.gengetopt_option)->required = (yyvsp[(2) - (2)].boolean);
@@ -1850,7 +1904,9 @@ yyreduce:
     break;
 
   case 32:
-#line 443 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 443 "../../src/parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (2)].gengetopt_option);
 			  	(yyval.gengetopt_option)->type = (yyvsp[(2) - (2)].argtype);
@@ -1858,7 +1914,9 @@ yyreduce:
     break;
 
   case 33:
-#line 448 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 448 "../../src/parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (4)].gengetopt_option);
 			  	(yyval.gengetopt_option)->type_str = strdup((yyvsp[(4) - (4)].str));
@@ -1866,7 +1924,9 @@ yyreduce:
     break;
 
   case 34:
-#line 453 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 453 "../../src/parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (4)].gengetopt_option);
 			  	(yyval.gengetopt_option)->details = strdup((yyvsp[(4) - (4)].str));
@@ -1874,7 +1934,9 @@ yyreduce:
     break;
 
   case 35:
-#line 458 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 458 "../../src/parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (4)].gengetopt_option);
 			  	(yyval.gengetopt_option)->acceptedvalues = (yyvsp[(4) - (4)].ValueList);
@@ -1882,7 +1944,9 @@ yyreduce:
     break;
 
   case 36:
-#line 463 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 463 "../../src/parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (4)].gengetopt_option);
 			  	(yyval.gengetopt_option)->default_string = strdup((yyvsp[(4) - (4)].str));
@@ -1890,7 +1954,9 @@ yyreduce:
     break;
 
   case 37:
-#line 468 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 468 "../../src/parser.yy"
     {
                 (yyval.gengetopt_option) = (yyvsp[(1) - (4)].gengetopt_option);
                 (yyval.gengetopt_option)->group_value = strdup((yyvsp[(4) - (4)].str));
@@ -1898,7 +1964,9 @@ yyreduce:
     break;
 
   case 38:
-#line 473 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 473 "../../src/parser.yy"
     {
                 (yyval.gengetopt_option) = (yyvsp[(1) - (4)].gengetopt_option);
                 (yyval.gengetopt_option)->mode_value = strdup((yyvsp[(4) - (4)].str));
@@ -1906,7 +1974,9 @@ yyreduce:
     break;
 
   case 39:
-#line 478 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 478 "../../src/parser.yy"
     {
                 (yyval.gengetopt_option) = (yyvsp[(1) - (4)].gengetopt_option);
                 (yyval.gengetopt_option)->dependon = strdup((yyvsp[(4) - (4)].str));
@@ -1914,7 +1984,9 @@ yyreduce:
     break;
 
   case 40:
-#line 483 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 483 "../../src/parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (2)].gengetopt_option);
 			  	(yyval.gengetopt_option)->arg_is_optional = true;
@@ -1922,7 +1994,9 @@ yyreduce:
     break;
 
   case 41:
-#line 488 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 488 "../../src/parser.yy"
     {
 			  	(yyval.gengetopt_option) = (yyvsp[(1) - (3)].gengetopt_option);
 			  	(yyval.gengetopt_option)->multiple = true;
@@ -1933,7 +2007,9 @@ yyreduce:
     break;
 
   case 42:
-#line 496 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 496 "../../src/parser.yy"
     {
           (yyval.gengetopt_option) = (yyvsp[(1) - (2)].gengetopt_option);
           (yyval.gengetopt_option)->type = ARG_FLAG;
@@ -1941,7 +2017,9 @@ yyreduce:
     break;
 
   case 43:
-#line 501 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 501 "../../src/parser.yy"
     {
           (yyval.gengetopt_option) = (yyvsp[(1) - (2)].gengetopt_option);
           (yyval.gengetopt_option)->hidden = true;
@@ -1949,7 +2027,9 @@ yyreduce:
     break;
 
   case 44:
-#line 506 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 506 "../../src/parser.yy"
     {
           (yyval.gengetopt_option) = (yyvsp[(1) - (2)].gengetopt_option);
           (yyval.gengetopt_option)->flagstat = (yyvsp[(2) - (2)].boolean);
@@ -1957,118 +2037,163 @@ yyreduce:
     break;
 
   case 45:
-#line 510 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 510 "../../src/parser.yy"
     { (yyval.gengetopt_option) = new gengetopt_option; }
     break;
 
   case 46:
-#line 514 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 514 "../../src/parser.yy"
     { (yyval.boolean) = 1; }
     break;
 
   case 47:
-#line 515 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 515 "../../src/parser.yy"
     { (yyval.boolean) = 0; }
     break;
 
   case 48:
-#line 519 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 519 "../../src/parser.yy"
     { (yyval.boolean) = 0; }
     break;
 
   case 49:
-#line 520 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 520 "../../src/parser.yy"
     { (yyval.boolean) = 1; }
     break;
 
   case 50:
-#line 521 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 521 "../../src/parser.yy"
     { (yyval.boolean) = 0; }
     break;
 
   case 51:
-#line 525 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 525 "../../src/parser.yy"
     { (yyval.boolean) = 1; }
     break;
 
   case 52:
-#line 526 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 526 "../../src/parser.yy"
     { (yyval.boolean) = 0; }
     break;
 
   case 53:
-#line 530 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 530 "../../src/parser.yy"
     { (yyval.str) = 0; }
     break;
 
   case 54:
-#line 531 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 531 "../../src/parser.yy"
     { (yyval.str) = (yyvsp[(3) - (3)].str); }
     break;
 
   case 55:
-#line 535 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 535 "../../src/parser.yy"
     { (yyval.str) = 0; }
     break;
 
   case 56:
-#line 536 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 536 "../../src/parser.yy"
     { (yyval.str) = (yyvsp[(3) - (3)].str); }
     break;
 
   case 57:
-#line 540 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 540 "../../src/parser.yy"
     { (yyval.str) = 0; }
     break;
 
   case 58:
-#line 541 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 541 "../../src/parser.yy"
     { (yyval.str) = (yyvsp[(3) - (3)].str); }
     break;
 
   case 59:
-#line 545 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 545 "../../src/parser.yy"
     { (yyval.ValueList) = new AcceptedValues; (yyval.ValueList)->insert((yyvsp[(1) - (1)].str)); }
     break;
 
   case 60:
-#line 546 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 546 "../../src/parser.yy"
     { (yyvsp[(1) - (3)].ValueList)->insert((yyvsp[(3) - (3)].str)); (yyval.ValueList) = (yyvsp[(1) - (3)].ValueList); }
     break;
 
   case 61:
-#line 550 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 550 "../../src/parser.yy"
     { (yyval.str) = (yyvsp[(1) - (1)].str); }
     break;
 
   case 62:
-#line 554 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 554 "../../src/parser.yy"
     { (yyval.multiple_size) = new multiple_size; }
     break;
 
   case 63:
-#line 555 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 555 "../../src/parser.yy"
     { (yyval.multiple_size) = new multiple_size((yyvsp[(2) - (3)].str), (yyvsp[(2) - (3)].str)); }
     break;
 
   case 64:
-#line 556 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 556 "../../src/parser.yy"
     { (yyval.multiple_size) = new multiple_size((yyvsp[(2) - (4)].str), "0"); free((yyvsp[(2) - (4)].str)); }
     break;
 
   case 65:
-#line 557 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 557 "../../src/parser.yy"
     { (yyval.multiple_size) = new multiple_size("0", (yyvsp[(3) - (4)].str)); free((yyvsp[(3) - (4)].str)); }
     break;
 
   case 66:
-#line 558 "parser.yy"
+
+/* Line 1455 of yacc.c  */
+#line 558 "../../src/parser.yy"
     { (yyval.multiple_size) = new multiple_size((yyvsp[(2) - (5)].str), (yyvsp[(4) - (5)].str)); free((yyvsp[(2) - (5)].str)); free((yyvsp[(4) - (5)].str)); }
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 2072 "parser.cc"
+
+/* Line 1455 of yacc.c  */
+#line 2197 "../../src/parser.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -2144,7 +2269,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -2161,7 +2286,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -2219,14 +2344,11 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
   yyerror_range[1] = yylloc;
   /* Using YYLLOC is tempting, but would change the location of
-     the look-ahead.  YYLOC is available though.  */
+     the lookahead.  YYLOC is available though.  */
   YYLLOC_DEFAULT (yyloc, (yyerror_range - 1), 2);
   *++yylsp = yyloc;
 
@@ -2251,7 +2373,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -2262,7 +2384,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval, &yylloc);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -2288,6 +2410,8 @@ yyreturn:
 }
 
 
-#line 561 "parser.yy"
+
+/* Line 1675 of yacc.c  */
+#line 561 "../../src/parser.yy"
 
 
